@@ -1,4 +1,5 @@
-package MyGlobalSubs;
+package # Dear CPAN, please don't index this
+MyGlobalSubs;
 use Devel::GlobalSub qw(test_a test_b);
 
 sub test_a {
