@@ -3,7 +3,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 unshift @INC, \&_inject;
 my $seen;
@@ -70,7 +70,7 @@ Devel::GlobalSub - Automagically import a subroutine into all namespaces
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =head1 SYNOPSIS
 
@@ -118,7 +118,7 @@ If that's is not possible for you for any reason, then you can simply call your
 	#!/usr/bin/perl
 	# File: some_script.pl
 	
-	use MyGlobalSubs; # <- Very first thing in your code
+	use MyGlobalSubs qw(exported_1 exported_2); # <- Very first thing in your code
 	use strict;
 	use warnings;
 	
@@ -142,7 +142,7 @@ It needs to receive the names of the subroutines you want to export everywhere.
 
 	# File: MyGlobalSubs.pm
 
-    use Devel::GlobalSub qw(global_sub_1 global_sub_2); # Just the names, not references
+	use Devel::GlobalSub qw(global_sub_1 global_sub_2); # Just the names, not references
 	use strict;
 	use warnings;
 	
